Package: html2pdfR
Type: Package
Title: Convert Local 'HTML' and 'XHTML' Files to 'PDF'
Version: 0.1.0
Authors@R: person("Lijin", "Arakkandathil Thekkathil", email = "lijin5673@gmail.com", role = c("aut", "cre"))
Description: Provides functions for converting local 'HTML' and 'XHTML' files to 'PDF' using an external backend. The package includes helper functions for backend setup, file conversion, and an optional 'Tk' graphical interface.
License: GPL-3
Encoding: UTF-8
Imports: utils, tools, tcltk
Suggests: roxygen2, testthat
URL: https://github.com/Lijin-5673/html2pdfR
BugReports: https://github.com/Lijin-5673/html2pdfR/issues
NeedsCompilation: no
Config/roxygen2/version: 8.0.0
Packaged: 2026-05-09 15:01:02 UTC; lijin
Author: Lijin Arakkandathil Thekkathil [aut, cre]
Maintainer: Lijin Arakkandathil Thekkathil <lijin5673@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-13 19:20:02 UTC
Built: R 4.6.0; ; 2026-05-13 20:12:08 UTC; unix
