% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/paths.R
\name{backend_root}
\alias{backend_root}
\title{Get backend root directory}
\usage{
backend_root()
}
\value{
Path to the package user data directory.
}
\description{
Get backend root directory
}
